PROC CHECK
function NAtoZero(xvar);
  if xvar = notappl then
    xvar = 0
  endif;
  NAtoZero = xvar;
end;

PROC MICSHH
{ Check identification and structure }
preproc
level 0
  write workhead;
  xcluster = notappl;

{ Cluster  &  Household  Totals }
  chhtot = 0;              {Total households                   }
  chhcmp = 0;              {Total completed households         }
  chhinc = 0;              {Total incomplete households        }
  chlint = 0; xhlint = 0;  {Total household members interviewed}
  chltot = 0; xhltot = 0;  {Total household members listed     }
  cwmelig= 0; xwmelig= 0;  {Total eligible women               }
  cwmint = 0; xwmint = 0;  {Total eligible women interviewed   }
  cwmtot = 0; xwmtot = 0;  {Total eligible women found         }
  cchelig= 0; xchelig= 0;  {Total eligible children            }
  cchint = 0; xchint = 0;  {Total eligible children interviewed}
  cchtot = 0; xchtot = 0;  {Total eligible children found      }
   chtot = 0;  wmtot = 0;  {Total children and women from reading all of data file }

level 1
  wcluster = HI1;
  whnumber = HI2;
  whresult = HI10;

  { Set cluster totals }
  chhtot   = chhtot + 1;
  if HI10 = 1 then
    chhcmp = chhcmp + 1
  else
    chhinc = chhinc + 1
  endif;
  chlint  = chlint  + NAtoZero(HIMEM);
  cwmelig = cwmelig + NAtoZero(HI11);
  cwmint  = cwmint  + NAtoZero(HI12);
  cchelig = cchelig + NAtoZero(HI13);
  cchint  = cchint  + NAtoZero(HI14);

  { Set household totals }
  xhlint  = NAtoZero(HIMEM);
  xhltot  = 0;
  xwmelig = NAtoZero(HI11);
  xwmint  = NAtoZero(HI12);
  xwmtot  = 0;
  xchelig = NAtoZero(HI13);
  xchint  = NAtoZero(HI14);
  xchtot  = 0;
  xcluster = HI1;
  write    workbody;

  if soccurs(MODHI) <> 1 then
    e=errmsg(0069)
  endif;

  if HI10 = 1 then

    x = soccurs(MODHL);
    if x <> HIMEM then
      e=errmsg(0070,x,HIMEM)
    else
      x = count(MODHL where HL5 > 0);
      if x <> HI11 then
        e=errmsg(0207,x,HI11)
      endif;
      x = count(MODHL where HL7 > 0);
      if x <> HI13 then
        e=errmsg(0206,x,HI13)
      endif;
    endif;

    x = count(MODED);
    if x <> HIMEM then
      e=errmsg(0071,x,HIMEM)
    endif;

    { count HH members eligible for education and child labour modules }
    clctr = 0;
    i = 1;
    while i <= noccurs(MODHL) do
      if HL4(i) >= 5 and HL4(i) <= 14 then
        clctr = clctr + 1
      endif;
      i = i + 1;
    enddo;
    x = count(MODCL);
    if x <> clctr then
      e=errmsg(0072,x,clctr)
    endif;

    if soccurs(MODWS) <> 1 then
      e=errmsg(0073)
    endif;

    if soccurs(MODSI) <> 1 then
      e=errmsg(0074)
    endif;

    i = 1;
    while i <= HIMEM do
      xeligw(i) = HL5(i);
      xeligl(i) = HL6(i);
      xeligc(i) = HL7(i);
      i = i + 1
    enddo

  else

    if soccurs(MODHL) <> 0 then
      e=errmsg(0070,soccurs(MODHL),0);
    endif;
    if soccurs(MODED) <> 0 then
      e=errmsg(0071,soccurs(MODED),0);
    endif;
    if soccurs(MODCL) <> 0 then
      e=errmsg(0072,soccurs(MODCL),0);
    endif;
    if soccurs(MODWS) <> 0 then
      e=errmsg(0073);
    endif;
    if soccurs(MODSI) <> 0 then
      e=errmsg(0074);
    endif;

  endif;

  i = 1;
  while i <= noccurs(MODHL) do

    whline = i;
    wwelig = HL5(i);
    wwline = notappl;
    wcelig = HL7(i);
    wcline = notappl;

    chltot = chltot + 1;
    xhltot = xhltot + 1;

    if (HL5(i) <> HL1(i) and  HL3(i) =  2 and HL4(i) >= 15 and HL4(i) <= 49) or
       (HL5(i) <> 0      and (HL3(i) <> 2 or  HL4(i) <  15 or  HL4(i) >  49)) then
      e=errmsg(0221,i);
    endif;
    if HL6(i) = HL1(i) or HL6(i) > HIMEM or
      (HL6(i) =  0 and  HL4(i) >= 5 and HL4(i) <= 14) or
      (HL6(i) <> 0 and (HL4(i) <  5 or  HL4(i) >  14)) then
      e=errmsg(0222,i);
    endif;
    if HL7(i) = HL1(i) or HL7(i) > HIMEM or
      (HL7(i) =  0 and HL4(i) <  5) or
      (HL7(i) <> 0 and HL4(i) >= 5) then
      e=errmsg(0223,i);
    endif;

    WILNNO = i;
    if loadcase(MICSWM, HI1, HI2, WILNNO) then
      cwmtot = cwmtot + 1;
      xwmtot = xwmtot + 1;
      wwline = WILNNO;

      if HL5(i) = 0 then
        e=errmsg(0211,WILNNO);
      endif;

      { Check person is listed as eligible }
      if WILNNO < 1 or WILNNO > HIMEM then
        e=errmsg(0201,WILNNO,HIMEM);
      else
        if xeligw(WILNNO) = WILNNO then
           xeligw(WILNNO) = -WILNNO;
        elseif xeligw(WILNNO) = -WILNNO then
          e=errmsg(0202,WILNNO);
        else
          e=errmsg(0203,WILNNO,"woman");
        endif
      endif;

      lb = 0; if CM11X = "Y" then lb = 1 endif;
      { Women's modules that should exist }
      if soccurs(MODWI) <> 1 then
        e=errmsg(1070,WILNNO)
      endif;
      if soccurs(MODCM) <> 1 then
        e=errmsg(1071,WILNNO)
      endif;
      if soccurs(MODTT) <> lb then
        e=errmsg(1072,WILNNO)
      endif;
      if soccurs(MODMN) <> lb then
        e=errmsg(1073,WILNNO)
      endif;
      if soccurs(MODCU) <> 1 then
        e=errmsg(1074,WILNNO)
      endif;
      if soccurs(MODHA) <> 1 then
        e=errmsg(1075,WILNNO)
      endif;

    endif;  { End of women's questionnaire }

    CHLNNO = i;
    if loadcase(MICSCH, HI1, HI2, CHLNNO) then
      cchtot = cchtot + 1;
      xchtot = xchtot + 1;
      wcline = CHLNNO;

      if CHCTNO <> HL7(CHLNNO) then
        e=errmsg(3010,CHCTNO,HL7(CHLNNO))
      endif;
      if HL7(i) = 0 then
        e=errmsg(0210,CHLNNO);
      endif;

      { Check person is listed as eligible }
      if CHLNNO < 1 or CHLNNO > HIMEM then
        e=errmsg(0201,CHLNNO,HIMEM);
      else
        if xeligc(CHLNNO) = CHCTNO then
           xeligc(CHLNNO) = -CHLNNO;
        elseif xeligc(CHLNNO) = -CHLNNO then
          e=errmsg(0202,CHLNNO);
        else
          e=errmsg(0203,CHLNNO,"child");
        endif;
      endif;

      { Child modules that should exist }
      if soccurs(MODBR) <> 1 then
        e=errmsg(3070,WILNNO)
      endif;
      if soccurs(MODVA) <> 1 then
        e=errmsg(3071,CHLNNO)
      endif;
      if soccurs(MODBF) <> 1 then
        e=errmsg(3072,CHLNNO)
      endif;
      if soccurs(MODCI) <> 1 then
        e=errmsg(3073,CHLNNO)
      endif;
      if soccurs(MODML) <> 1 then
        e=errmsg(3074,CHLNNO)
      endif;
      if soccurs(MODIM) <> 1 then
        e=errmsg(3075,CHLNNO)
      endif;
      if soccurs(MODAN) <> 1 then
        e=errmsg(3076,CHLNNO)
      endif;

    endif;

    write workbod2;

    i = i + 1
  enddo;

  i = 1;
  while i <= noccurs(MODCL) do

    cllnno = CL1(i);
    { Check person is listed as eligible }
    if cllnno < 1 or cllnno > HIMEM then
      e=errmsg(0231,cllnno,HIMEM);
    else
      if xeligl(cllnno) = HL6(cllnno) then
         xeligl(cllnno) = -cllnno;
      elseif xeligl(cllnno) = -cllnno then
        e=errmsg(0232,cllnno);
      else
        e=errmsg(0233,cllnno);
      endif;
    endif;

    i = i + 1
  enddo;

postproc
level 1
  i = 1;
  while i <= HIMEM do
    if xwmint <> xwmtot and xeligw(i) > 0 then
      e=errmsg(0204,"woman",i)
    endif;
    if xchint <> xchtot and xeligc(i) > 0 then
      e=errmsg(0204,"child",i)
    endif;
    if xeligl(i) > 0 then
      e=errmsg(0234,i)
    endif;
    i = i + 1
  enddo;

  if xhlint  <> xhltot then
    e=errmsg(0205,xhltot,xhlint)
  endif;
  if xwmelig <  xwmint then
    e=errmsg(0207,xwmint,xwmelig)
  endif;
  if xwmint  <> xwmtot then
    e=errmsg(0209,xwmtot,xwmint)
  endif;
  if xchelig <  xchint then
    e=errmsg(0206,xchint,xchelig)
  endif;
  if xchint  <> xchtot then
    e=errmsg(0208,xchtot,xchint)
  endif;

level 0

  if chlint  <> chltot then
    e=errmsg(0205,xhltot,xhlint)
  endif;
  if cwmelig <  cwmint then
    e=errmsg(0207,cwmint,cwmelig)
  endif;
  if cwmint  <> cwmtot then
    e=errmsg(0209,cwmtot,cwmint)
  endif;
  if cchelig <  cchint then
    e=errmsg(0206,cchint,cchelig)
  endif;
  if cchint  <> cchtot then
    e=errmsg(0208,cchtot,cchint)
  endif;

  write worktlhd;
  write worktail;

  { Read through the whole of the women's data and count the cases }
  xw=locate(MICSWM,>,"  0  0 0");
  xw=loadcase(MICSWM);  { Extra loadcase needed due to bug dealing with file pointer }
  while xw do
    xw = loadcase(MICSWM);
    wmtot = wmtot + 1
  enddo;
  if wmtot <> cwmtot then
    e=errmsg(0242,cwmtot,wmtot);
  endif;

  { Read through the whole of the children's data and count the cases }
  xc=locate(MICSCH,>,"  0  0 0");
  xc=loadcase(MICSCH);  { Extra loadcase needed due to bug dealing with file pointer }
  while xc do
    xc = loadcase(MICSCH);
    chtot = chtot + 1
  enddo;
  if chtot <> cchtot then
    e=errmsg(0241,chtot,cchtot);
  endif;
