PROC EDITING

function validyr(xvar);
  validyr = (!special(xvar) & xvar <= 9996)
end;

function valid(xvar);
  valid = (!special(xvar) and xvar < 96)
end;

function NAtoZero(xvar);
  if xvar = notappl then
    xvar = 0
  endif;
  NAtoZero = xvar;
end;

function vcheck(vcheckd,vcheckm,vchecky);
  box       vchecky   : vcheckm               : vcheckd    => vcheckx; { !!! }
                 9997 : 97                    : 97         => 1;
  1995-2000,9996-9999 : 1,3,5,7,8,10,12,96-99 : 1-31,96-99 => 0;
  1995-2000,9996-9999 : 4,6,9,11              : 1-30,96-99 => 0;
  1995-2000,9996-9999 : 2                     : 1-28,96-99 => 0;
  1996,2000           : 2                     : 29         => 0;       { leap year }
              notappl : notappl               : 66         => 0;
              notappl : notappl               : 44         => 0;
              notappl : notappl               : 0          => 0;
                      :                       :            => 1;
  endbox;
  if vchecky = HI3Y & vcheckm <= 12 & vcheckm > HI3M then
    vcheckx = 2
  elseif vchecky = HI3Y & vcheckm = HI3M &
         vcheckd <= 31 & vcheckd > HI3D then
    vcheckx = 2
  endif;
  vcheck = vcheckx;
end;

function vdate(vday, vmonth, vyear)
  vdate = (vday*100+vmonth)*10000+vyear;
end;

PROC MICSHH
preproc
level 0
maxmem = 50;      { maximum number of household members }
maxcl  = 20;      { maximum number of entries in child labor module }
minage = 15;      { minimum age of eligible women }
maxage = 49;      { maximum age of eligible women }
minab  = 144;     { minimum age at birth in months = 12 years }
chhlth = 4;       { maximum age at which child is included in child health module - excludes exact age 5 }
chlabl = 5;       { minimum age at which child is included in child labor module - includes exact age 5 }
chlabu = 14;      { maximum age at which child is included in child labor module - excludes exact age 15 }

level 1
box HI3Y :     HI3M        : HI3D => err;
         : 1,3,5,7,8,10,12 : 1-31 => 0;
         : 4,6,9,11        : 1-30 => 0;
         : 2               : 1-28 => 0;
    2000 : 2               :   29 => 0;   { leap year }
         :                 :      => 1;
endbox;
if err then
  e=errmsg(0016,HI3D,HI3M,HI3Y);
endif;
dd = (HI3Y*100 + HI3M)*100 + HI3D;
ss = sysdate("yyyymmdd");
if dd >= ss or dd < 19991113 then      { replace "19991113" with earliest interview date in yyyymmdd format }
  e=errmsg(0016,HI3D,HI3M,HI3Y);
endif;

di = cmcode(HI3M,HI3Y);

  { cluster : urbrur }
box HI1     : HI6 => err;
    001-100 :  1  => 0;
    101-200 :  2  => 0;
    201-300 :  1  => 0;
    301-400 :  2  => 0;
    401-500 :  1  => 0;
    501-600 :  2  => 0;
    601-700 :  1  => 0;
    701-800 :  2  => 0;
            :     => 1;
endbox;
if err then
  e=errmsg(0011,"HI6",HI6,HI1);
endif;

  { cluster : region }
box HI1     : HI7 => err;
    001-100 :  1  => 0;
    101-200 :  1  => 0;
    201-300 :  2  => 0;
    301-400 :  2  => 0;
    401-500 :  3  => 0;
    501-600 :  3  => 0;
    601-700 :  4  => 0;
    701-800 :  4  => 0;
            :     => 1;
endbox;
if err then
  e=errmsg(0011,"HI7",HI7,HI1);
endif;

if HI10 = 1 then     { Complete interview }

  { Household Cover Page }
  if HI12 > HI11 then
    e=errmsg(0014,HI12,HI11);
  endif;

  if HI14 > HI13 then
    e=errmsg(0013,HI14,HI13);
  endif;

  if HIMEM < HI11+HI13 then
    e=errmsg(0015,HI11,HI13,HIMEM);
  endif;

  { check for age of head of household below 15 }
  if HIMEM >= 1 and HL4(1) < 15 then
    e=errmsg(0050,HL4(1))
  endif;

  { Household Listing Module }
  i = 1;
  while i <= noccurs(MODHL) do

    if HL3(i) = 2 and HL4(i) >= minage and HL4(i) <= maxage then
      if HL5(i) <> HL1(i) then
        e=errmsg(0101,HL1(i),HL5(i));
      endif;
    else
      if HL5(i) <> 0 then
        e=errmsg(0102,HL1(i),HL5(i));
      endif;
    endif;

    if HL4(i) >= chlabl and HL4(i) <= chlabu then
      if HL6(i) = 0 or HL6(i) = HL1(i) then
        e=errmsg(0121,HL1(i),HL6(i));
      elseif HL6(i) > HIMEM then
        e=errmsg(0120,HL1(i),HL6(i));
      endif;
    else
      if HL6(i) <> 0 then
        e=errmsg(0122,HL1(i),HL6(i));
      endif
    endif;

    m = HL6(i);
    if m <> 0 and HL11(i) = 1 then
      if HL3(m) <> 2 or HL4(m) < HL4(i)+12 then
        e=errmsg(0162,i,HL3(m),HL4(m),m);
      endif;
    endif;

    if HL4(i) <= chhlth then
      if HL7(i) = 0 or HL7(i) = HL1(i) then
        e=errmsg(0131,HL1(i),HL7(i));
      elseif HL7(i) > HIMEM then
        e=errmsg(0130,HL1(i),HL7(i));
      endif;
    else
      if HL7(i) <> 0 then
        e=errmsg(0132,HL1(i),HL7(i));
      endif
    endif;

    m = HL7(i);
    if m <> 0 and HL11(i) = 1 then
      if HL3(m) <> 2 or HL4(m) < HL4(i)+12 then
        e=errmsg(0163,i,HL3(m),HL4(m),m);
      endif;
    endif;

    i = i + 1
  enddo;

  { Education Module }
  i = 1;
  while i <= noccurs(MODED) do
    lineno = ED14(i);

    if ED16A(i) <> notappl then
      lev = ED16A(i);
      grd = ED16B(i);
      box lev : grd      => err; { Fix maximum grade for each possible level }
              : 96,97,99 => 0;   { Inconsistent, missing, DK grade }
            1 : 0-6      => 0;   { Primary }
            2 : 0-6      => 0;   { Secondary }
            3 : 0-5      => 0;   { Higher }
            4 : 0-6      => 0;   { Non-standard curriculum }
            7 :          => 0;   { Missing level }
            9 :          => 0;   { DK level }
              :          => 1;
      endbox;
      if err then
        e=errmsg(0090,lineno,"ED16",lev,grd);
      endif;
    endif;

    if ED20A(i) <> notappl then
      lev = ED20A(i);
      grd = ED20B(i);
      box lev : grd      => err; { Fix maximum grade for each possible level }
              : 96,97,99 => 0;   { Inconsistent, missing, DK grade }
            1 : 0-4      => 0;   { Preschool}
            2 : 0-6      => 0;   { Primary }
            3 : 0-6      => 0;   { Secondary }
            4 : 0-6      => 0;   { Non-standard curriculum }
            7 :          => 0;   { Missing level }
            9 :          => 0;   { DK level }
              :          => 1;
      endbox;
      if err then
        e=errmsg(0090,lineno,"ED20",lev,grd);
      endif;
    endif;

    if ED22A(i) <> notappl then
      lev = ED22A(i);
      grd = ED22B(i);
      box lev : grd      => err; { Fix maximum grade for each possible level }
              : 96,97,99 => 0;   { Inconsistent, missing, DK grade }
            1 : 0-4      => 0;   { Preschool}
            2 : 0-6      => 0;   { Primary }
            3 : 0-6      => 0;   { Secondary }
            4 : 0-6      => 0;   { Non-standard curriculum }
            7 :          => 0;   { Missing level }
            9 :          => 0;   { DK level }
              :          => 1;
      endbox;
      if err then
        e=errmsg(0090,lineno,"ED22",lev,grd);
      endif;
    endif;

    if !special(ED22A(i)) & !special(ED20A(i)) &
      (ED22A(i) > ED20A(i) or (ED22A(i) = ED20A(i) & valid(ED22B(i)) & ED22B(i) > ED20B(i))) then
      e=errmsg(0260,lineno,ED22A(i),ED22B(i),ED20A(i),ED20B(i));
    endif;

    i = i + 1
  enddo;

  { Check if WS5 should be applicable }
  ch03 = count(MODHL where HL4 <= 3);
  if ch03 <=> WS5 = 8 then
    e=errmsg(0170,WS5,ch03)
  endif;

{ --------------------------------------------------------------------------- }
{ Women's questionnaires }

  foundwm = 0;
  ln = 1;
  while ln <= noccurs(MODHL) do
    if HL5(ln) <> 0 then
      if loadcase(MICSWM, HI1, HI2, HL1(ln)) then
        foundwm = foundwm + 1;

        { Women's Information Module }
        if WI1 <> WILNNO then
          e=errmsg(1000,ln,WI1,WILNNO);
        endif;

        udob = di - minage*12;
        ldob = di - maxage*12 - 11;
        if WI3AY < 9997 then
          ldob = setlb(WI3AM,WI3AY,0);
          udob = setub(WI3AM,WI3AY,9999);
          if udob < di - maxage*12 - 11 or ldob > di - minage*12 then
            e=errmsg(1063,ln,WI3AM,WI3AY);
          endif;
        else
          if WI3B >= 96 then
            e=errmsg(1060,ln,WI3AM,WI3AY,WI3B);
          else
            udob = di - WI3B*12;
            ldob = udob - 11;
          endif;
          if WI3B <> HL4(WI1) then
            e=errmsg(1061,ln,WI3B,HL4(WI1));
          endif;
        endif;

        { Child Mortality module }
        if CM1 = 1 then
          ldobfc = ldob + minab;
          udobfc = di;
          if CM2AY < 9997 then
            ldobfc = setlb(CM2AM,CM2AY,0);
            udobfc = setub(CM2AM,CM2AY,9999);
            if udobfc < ldob + minab then
              e=errmsg(2010,ln,CM2AD,CM2AM,CM2AY,int(minab/12));
            elseif ldobfc > di then
              e=errmsg(2011,ln,CM2AD,CM2AM,CM2AY,HI3D,HI3M,HI3Y);
            endif;
          endif;

          { Check for at least one child living at home - otherwise CM3 must be 2 }
          if CM4A = 0 and CM4B = 0 then
            e=errmsg(2030,ln,"CM4A",CM4A,"CM4B",CM4B);
          endif;

          { Check for at least one child living away - otherwise CM5 must be 2 }
          if CM6A = 0 and CM6B = 0 then
            e=errmsg(2030,ln,"CM6A",CM6A,"CM6B",CM6B);
          endif;

          { Check for at least one child who died - otherwise CM7 must be 2 }
          if CM8A = 0 and CM8B = 0 then
            e=errmsg(2030,ln,"CM8A",CM8A,"CM8B",CM8B);
          endif;

          { Count up total children ever born }
          x = NAtoZero(CM4A)+NAtoZero(CM4B)+
              NAtoZero(CM6A)+NAtoZero(CM6B)+
              NAtoZero(CM8A)+NAtoZero(CM8B);
          { Check count of children ever born with total }
          if x <> CM9 then
            e=errmsg(2080,ln,CM9,CM4A,CM4B,CM6A,CM6B,CM8A,CM8B)
          endif;

          ldoblc = ldobfc;
          udoblc = di;
          if CM11Y < 9997 then
            ldoblc = setlb(CM11M,CM11Y,0);
            udoblc = setub(CM11M,CM11Y,9999);
            if udoblc < ldob + minab then
              e=errmsg(2014,ln,CM11D,CM11M,CM11Y,int(minab/12));
            elseif ldoblc > di then
              e=errmsg(2015,ln,CM11D,CM11M,CM11Y,HI3D,HI3M,HI3Y);
            endif;
          endif;

          if CM9 = 1 then
            if (CM11Y <> CM2AY or CM11M <> CM2AM or CM11D <> CM2AD) then
              e=errmsg(2090,ln,CM2AD,CM2AM,CM2AY,CM11D,CM11M,CM11Y);
            endif;
          else
            if ldobfc > udoblc then
              e=errmsg(2095,ln,CM11D,CM11M,CM11Y,CM2AD,CM2AM,CM2AY);
            endif;
          endif;

          if CM11X = "Y" <=> (CM11Y <> HI3Y and (CM11Y <> HI3Y-1 or
                             (CM11M <= HI3M and (CM11M <> HI3M   or
                              CM11D <= HI3D )))) then
            e=errmsg(2020,ln,CM11D,CM11M,CM11Y,HI3D,HI3M,HI3Y,CM11X);
          endif;

        endif;

        if CM11X = "Y" then

          { Tetanus Toxoid module }
          if (valid(TT3) or TT3 = notappl) and (valid(TT5) or TT5 = notappl) and valid(TT7) and
             TT7 <> NAtoZero(TT3) + NAtoZero(TT5) then
            e=errmsg(2017,ln,TT3,TT5,TT7);
          endif;

          { Maternal and Newborn Health module }
          miss = 0;
          if MN2A = 7 then miss = miss + 1 endif;
          if MN2B = 7 then miss = miss + 1 endif;
          if MN2C = 7 then miss = miss + 1 endif;
          if MN2D = 7 then miss = miss + 1 endif;
          if MN2F = 7 then miss = miss + 1 endif;
          if MN2Z = 7 then miss = miss + 1 endif;
          if miss <> 0 and miss <> 6 then
            e=errmsg(0190,ln,"MN2");
          else
            if MN2Z = 0 and (MN2A <> 0 or MN2B <> 0 or MN2C <> 0 or MN2D <> 0 or MN2F <> 0) then
              e=errmsg(0191,ln,"MN2");
            else
              if MN2Z <> 0 and (MN2A = 0 and MN2B = 0 and MN2C = 0 and MN2D = 0 and MN2F = 0) then
                e=errmsg(0191,ln,"MN2");
              endif
            endif
          endif;

          miss = 0;
          if MN3A = 7 then miss = miss + 1 endif;
          if MN3B = 7 then miss = miss + 1 endif;
          if MN3C = 7 then miss = miss + 1 endif;
          if MN3D = 7 then miss = miss + 1 endif;
          if MN3E = 7 then miss = miss + 1 endif;
          if MN3F = 7 then miss = miss + 1 endif;
          if MN3Z = 7 then miss = miss + 1 endif;
          if miss <> 0 and miss <> 7 then
            e=errmsg(0190,ln,"MN3");
          else
            if MN3Z = 0 and (MN3A <> 0 or MN3B <> 0 or MN3C <> 0 or MN3D <> 0 or MN3E <> 0 or MN3F <> 0) then
              e=errmsg(0191,ln,"MN3");
            elseif MN3Z <> 0 and (MN3A = 0 and MN3B = 0 and MN3C = 0 and MN3D = 0 and MN3E = 0 and MN3F = 0) then
              e=errmsg(0191,ln,"MN3");
            endif
          endif;

          { Check special answers in MN6 }
          if MN5 = 1 then
            if (MN6A = 9 <=>  MN6 <>9999) or
               (MN6A  = 7 <=> MN6 <> 9997) then
              e=errmsg(0004,ln,"MN6");
            elseif MN6 < 9997 and MN6%100 <> 0 and MN6%100 <> 50 then
              e=errmsg(0003,ln,"MN6")
            endif;
          endif;

        endif;

        { Contraceptive Use module }
        if CU3 = 1 then
          miss = 0;
          if CU4A = 97 then miss = miss + 1 endif;
          if CU4B = 97 then miss = miss + 1 endif;
          if CU4C = 97 then miss = miss + 1 endif;
          if CU4D = 97 then miss = miss + 1 endif;
          if CU4E = 97 then miss = miss + 1 endif;
          if CU4F = 97 then miss = miss + 1 endif;
          if CU4G = 97 then miss = miss + 1 endif;
          if CU4H = 97 then miss = miss + 1 endif;
          if CU4I = 97 then miss = miss + 1 endif;
          if CU4J = 97 then miss = miss + 1 endif;
          if CU4K = 97 then miss = miss + 1 endif;
          if CU4L = 97 then miss = miss + 1 endif;
          if CU4M = 97 then miss = miss + 1 endif;
          if CU4N = 97 then miss = miss + 1 endif;
          if miss <> 0 and miss <> 14 then
            e=errmsg(0190,ln,"CU4");
          else
            if CU4A = 0 and CU4B = 0 and CU4C = 0 and CU4D = 0 and CU4E = 0 and CU4F = 0 and CU4G = 0 and
               CU4H = 0 and CU4I = 0 and CU4J = 0 and CU4K = 0 and CU4L = 0 and CU4M = 0 and CU4N = 0 then
              e=errmsg(0192,ln,"CU4");
            endif
          endif;
        endif;

      endif; { Woman loaded }

    endif; { Woman eligible }

    ln = ln + 1;
  enddo; { Loop for women }

{ --------------------------------------------------------------------------- }
{ Children's questionnaires }

  foundch = 0;
  ln = 1;
  while ln <= noccurs(MODHL) do
    if HL7(ln) <> 0 then
      if loadcase(MICSCH, HI1, HI2, HL1(ln)) then
        foundch = foundch + 1;

        if CHCTNO <> HL7(CHLNNO) then
          e=errmsg(3010,CHCTNO,HL7(CHLNNO))
        endif;

        { Check age against age in household listing }
        if BR2 <> HL4(CHLNNO) then
          e=errmsg(3020,BR2,HL4(CHLNNO))
        endif;

        { Birth Registration Module }
        udob = di;
        ldob = di - chhlth*12 - 11;
        if BR3Y < 9997 then
          ldob = setlb(BR3M,BR3Y,0);
          udob = setub(BR3M,BR3Y,9999);
          if udob < di - chhlth*12 - 11 or ldob > di then
            e=errmsg(1063,ln,BR3M,BR3Y);
          endif;
        elseif BR2 >= 96 then
          e=errmsg(1060,ln,BR3M,BR3Y,BR2);
        endif;
        if valid(BR2) then
          { Lower bound of CMC date of birth }
          t = adjlba(ldob,udob,di,di,BR2);
          if t < 0 then
            e=errmsg(2171,ln,BR2,BR3D,BR3M,BR3Y);
          else
            ldob = t
          endif;
          { Upper bound of CMC date of birth }
          t = adjuba(ldob,udob,di,di,BR2);
          if t < 0 then
            e=errmsg(2171,ln,BR2,BR3D,BR3M,BR3Y);
          else
            udob = t
          endif;
        endif;

        { Care of Illness Module }
        if CI1 = 1 then
          if CI3I = 1 <=> (CI3A = 1 or CI3B = 1 or CI3C = 1 or CI3D = 1 or
                           CI3E = 1 or CI3F = 1 or CI3G = 1 or CI3H = 1) then
            e=errmsg(4000,ln,"CI3");
          endif;
        endif;

        if CI9 = 1 then
          miss = 0;
          if CI10A = 97 then miss = miss + 1 endif;
          if CI10B = 97 then miss = miss + 1 endif;
          if CI10C = 97 then miss = miss + 1 endif;
          if CI10D = 97 then miss = miss + 1 endif;
          if CI10E = 97 then miss = miss + 1 endif;
          if CI10F = 97 then miss = miss + 1 endif;
          if CI10G = 97 then miss = miss + 1 endif;
          if CI10H = 97 then miss = miss + 1 endif;
          if CI10I = 97 then miss = miss + 1 endif;
          if CI10J = 97 then miss = miss + 1 endif;
          if CI10K = 97 then miss = miss + 1 endif;
          if miss <> 0 and miss <> 11 then
            e=errmsg(0190,ln,"CI10");
          else
            if CI10A = 0 and CI10B = 0 and CI10C = 0 and CI10D = 0 and CI10E = 0 and
               CI10F = 0 and CI10G = 0 and CI10H = 0 and CI10I = 0 and CI10J = 0 and CI10K = 0 then
              e=errmsg(0192,ln,"CI10");
            endif
          endif;
        endif;

        miss = 0;
        if CI11A = 97 then miss = miss + 1 endif;
        if CI11B = 97 then miss = miss + 1 endif;
        if CI11C = 97 then miss = miss + 1 endif;
        if CI11D = 97 then miss = miss + 1 endif;
        if CI11E = 97 then miss = miss + 1 endif;
        if CI11F = 97 then miss = miss + 1 endif;
        if CI11G = 97 then miss = miss + 1 endif;
        if CI11H = 97 then miss = miss + 1 endif;
        if CI11I = 97 then miss = miss + 1 endif;
        if CI11J = 97 then miss = miss + 1 endif;
        if miss <> 0 and miss <> 10 then
          e=errmsg(0190,ln,"CI11");
        else
          if CI11A = 0 and CI11B = 0 and CI11C = 0 and CI11D = 0 and CI11E = 0 and
             CI11F = 0 and CI11G = 0 and CI11H = 0 and CI11I = 0 and CI11J = 0 then
            e=errmsg(0192,ln,"CI11");
          endif
        endif;

        { Malaria Module }
        if ML3 = 1 then
          miss = 0;
          if ML4A = 7 then miss = miss + 1 endif;
          if ML4B = 7 then miss = miss + 1 endif;
          if ML4C = 7 then miss = miss + 1 endif;
          if ML4D = 7 then miss = miss + 1 endif;
          if ML4Z = 7 then miss = miss + 1 endif;
          if miss <> 0 and miss <> 5 then
            e=errmsg(0190,ln,"ML4");
          else
            if ML4Z = 9 and (ML4A <> 0 or ML4B <> 0 or ML4C <> 0 or ML4D <> 0) then
              e=errmsg(0193,ln,"ML4");
            elseif ML4Z <> 9 and (ML4A = 0 and ML4B = 0 and ML4C = 0 and ML4D = 0) then
              e=errmsg(0193,ln,"ML4");
            endif
          endif;
        endif;

        if ML6 = 1 then
          miss = 0;
          if ML7A = 7 then miss = miss + 1 endif;
          if ML7B = 7 then miss = miss + 1 endif;
          if ML7C = 7 then miss = miss + 1 endif;
          if ML7D = 7 then miss = miss + 1 endif;
          if ML7Z = 7 then miss = miss + 1 endif;
          if miss <> 0 and miss <> 5 then
            e=errmsg(0190,ln,"ML7");
          else
            if ML7Z = 9 and (ML7A <> 0 or ML7B <> 0 or ML7C <> 0 or ML7D <> 0) then
              e=errmsg(0193,ln,"ML7");
            elseif ML7Z <> 9 and (ML7A = 0 and ML7B = 0 and ML7C = 0 and ML7D = 0) then
              e=errmsg(0193,ln,"ML7");
            endif
          endif;
        endif;

        { Immunization Module }
        if IM1 = 1 then
          if vcheck(IM2D,IM2M,IM2Y) then
            e=errmsg(4470,ln,"BCG",IM2D,IM2M,IM2Y);
          endif;
          if vcheck(IM3AD,IM3AM,IM3AY) then
            e=errmsg(4470,ln,"Polio 0",IM3AD,IM3AM,IM3AY);
          endif;
          if vcheck(IM3BD,IM3BM,IM3BY) then
            e=errmsg(4470,ln,"Polio 1",IM3BD,IM3BM,IM3BY);
          endif;
          if vcheck(IM3CD,IM3CM,IM3CY) then
            e=errmsg(4470,ln,"Polio 2",IM3CD,IM3CM,IM3CY);
          endif;
          if vcheck(IM3DD,IM3DM,IM3DY) then
            e=errmsg(4470,ln,"Polio 3",IM3DD,IM3DM,IM3DY);
          endif;
          if vcheck(IM4AD,IM4AM,IM4AY) then
            e=errmsg(4470,ln,"DPT 1",IM4AD,IM4AM,IM4AY);
          endif;
          if vcheck(IM4BD,IM4BM,IM4BY) then
            e=errmsg(4470,ln,"DPT 2",IM4BD,IM4BM,IM4BY);
          endif;
          if vcheck(IM4CD,IM4CM,IM4CY) then
            e=errmsg(4470,ln,"DPT 3",IM4CD,IM4CM,IM4CY);
          endif;
          if vcheck(IM5D,IM5M,IM5Y) then
            e=errmsg(4470,ln,"Measles",IM5D,IM5M,IM5Y);
          endif;
        endif;

        { Vaccination card exists }
        if IM1 = 1 then

          { Check if it has anything on it }
          if IM2D  = 0 and IM3AD = 0  and
             IM3BD = 0 and IM4AD = 0  and
             IM3CD = 0 and IM4BD = 0  and
             IM3DD = 0 and IM4CD = 0  and
             IM5D  = 0 then
            e=errmsg(4476,ln)

          else

            { If vaccinations are recorded - check the dates }

            v = 1;
            while v <= 9 do

              { Loop through all of the vaccinations }

              {    BCG or Pol 0 or DPT 1 or Measles }
              if v = 1 or v = 2 or v = 6 or v = 9 then
                xy =  0; xm =  0; xd =  0;
              elseif vd > 0 then
                xy = vy; xm = vm; xd = vd; xstring = vstring;
              endif;

              if     v = 1 then vd = IM2D ; vm = IM2M ; vy = IM2Y ; vstring = "BCG"
              elseif v = 2 then vd = IM3AD; vm = IM3AM; vy = IM3AY; vstring = "Polio 0"
              elseif v = 3 then vd = IM3BD; vm = IM3BM; vy = IM3BY; vstring = "Polio 1"
              elseif v = 4 then vd = IM3CD; vm = IM3CM; vy = IM3CY; vstring = "Polio 2"
              elseif v = 5 then vd = IM3DD; vm = IM3DM; vy = IM3DY; vstring = "Polio 3"
              elseif v = 6 then vd = IM4AD; vm = IM4AM; vy = IM4AY; vstring = "DPT 1"
              elseif v = 7 then vd = IM4BD; vm = IM4BM; vy = IM4BY; vstring = "DPT 2"
              elseif v = 8 then vd = IM4CD; vm = IM4CM; vy = IM4CY; vstring = "DPT 3"
              elseif v = 9 then vd = IM5D ; vm = IM5M ; vy = IM5Y ; vstring = "Measles"
              endif;

              { check vaccination given before interview ... }
              if vy = 0 or vy = 4444 or vy = 6666 then vy = 9999 endif;
              if validyr(vy) and (vy > HI3Y or (vy = HI3Y and
                 valid  (vm) and (vm > HI3M or (vm = HI3M and
                 valid  (vd) and  vd > HI3D )))) then
                e=errmsg(4471,ln,vstring,vd,vm,vy,HI3D,HI3M,HI3Y);
                vd = 0; vm = 0; vy = 0;
              endif;

              { ... and after date of birth }
              if vy < BR3Y or (vy = BR3Y and (vm < BR3M or (vm = BR3M and vd < BR3D))) then
                e=errmsg(4472,ln,vstring,vd,vm,vy,BR3D,BR3M,BR3Y);
                vd = 0; vm = 0; vy = 0;
              endif;

              { Check to see if vaccinations given in order }
              if vd <> 0 and xd <> 0 then
                if validyr(xy) and (vy < xy or (vy = xy and
                   valid  (xm) and (vm < xm or (vm = xm and
                   valid  (xd) and  vd < xd )))) then
                  e=errmsg(4473,ln,vstring,vd,vm,vy,xstring,xd,xm,xy);
                endif
              endif;

              v = v + 1;
            enddo;

            { Check to see if vaccinations were given on the same day }
            { There are two ways that this may happen, depending on the country }
            { 1) BCG and P1, P2 and D1, P3 and D2 }
            { 2) BCG and P0, P1 and D1, P2 and D2, P3 and D3 <- current default !!! modify as needed }
            if IM3AD <> IM2D  or IM3AM <> IM2M  or IM3AY <> IM2Y  or
               IM3BD <> IM4AD or IM3BM <> IM4AM or IM3BY <> IM4AY or
               IM3CD <> IM4BD or IM3CM <> IM4BM or IM3CY <> IM4BY or
               IM3DD <> IM4CD or IM3DM <> IM4CM or IM3DY <> IM4CY then
              e=errmsg(4474,ln,edit("99/99/9999",vdate(IM2D ,IM2M ,IM2Y )),
                               edit("99/99/9999",vdate(IM3AD,IM3AM,IM3AY)),
                               edit("99/99/9999",vdate(IM3BD,IM3BM,IM3BY)),
                               edit("99/99/9999",vdate(IM3CD,IM3CM,IM3CY)),
                               edit("99/99/9999",vdate(IM3DD,IM3DM,IM3DY)),
                               edit("99/99/9999",vdate(IM4AD,IM4AM,IM4AY)),
                               edit("99/99/9999",vdate(IM4BD,IM4BM,IM4BY)),
                               edit("99/99/9999",vdate(IM4CD,IM4CM,IM4CY)));
            endif;

          endif;

          {Other vaccinations reported by mother, but no others marked 66 on form }
          if IM6 <> 1 <=> (IM3AD = 66 or
                           IM3BD = 66 or IM4AD = 66 or
                           IM3CD = 66 or IM4BD = 66 or
                           IM3DD = 66 or IM4CD = 66 or
                           IM5D  = 66 or IM2D  = 66) then
            e=errmsg(4480,ln,IM6,edit("99/99/9999",vdate(IM2D ,IM2M ,IM2Y )),
                                 edit("99/99/9999",vdate(IM3AD,IM3AM,IM3AY)),
                                 edit("99/99/9999",vdate(IM3BD,IM3BM,IM3BY)),
                                 edit("99/99/9999",vdate(IM3CD,IM3CM,IM3CY)),
                                 edit("99/99/9999",vdate(IM3DD,IM3DM,IM3DY)),
                                 edit("99/99/9999",vdate(IM4AD,IM4AM,IM4AY)),
                                 edit("99/99/9999",vdate(IM4BD,IM4BM,IM4BY)),
                                 edit("99/99/9999",vdate(IM4CD,IM4CM,IM4CY)),
                                 edit("99/99/9999",vdate(IM5D ,IM5M ,IM5Y )));
          endif;

        endif;

        { Anthropometric Module }
        hwsex = HL3(CHLNNO);
        hwage = di - ldob;
        if hwsex = 1 then
          box hwage : WEIGHT     => hwerr;
               0- 2 :  0.5- 10.0 => 0;
               3- 5 :  1.0- 13.0 => 0;
               6- 8 :  2.0- 15.0 => 0;
               9-11 :  3.0- 16.5 => 0;
              12-14 :  4.0- 17.5 => 0;
              15-17 :  4.0- 18.5 => 0;
              18-20 :  4.0- 19.5 => 0;
              21-23 :  4.5- 20.5 => 0;
              24-26 :  4.5- 23.0 => 0;
              27-29 :  5.0- 24.0 => 0;
              30-32 :  5.0- 24.5 => 0;
              33-35 :  5.0- 25.5 => 0;
              36-38 :  5.0- 26.0 => 0;
              39-41 :  5.0- 27.0 => 0;
              42-44 :  5.0- 29.0 => 0;
              45-47 :  5.0- 29.0 => 0;
              48-50 :  5.0- 30.0 => 0;
              51-53 :  5.0- 31.0 => 0;
              54-56 :  5.5- 32.0 => 0;
              57-60 :  5.5- 33.0 => 0;
              61-72 :  5.5- 34.0 => 0;
                    :            => 1;
          endbox
        else
          box hwage : WEIGHT     => hwerr;
               0- 2 :  0.5-  9.0 => 0;
               3- 5 :  1.0- 12.0 => 0;
               6- 8 :  2.0- 14.0 => 0;
               9-11 :  2.5- 15.5 => 0;
              12-14 :  3.0- 16.5 => 0;
              15-17 :  3.5- 17.5 => 0;
              18-20 :  3.5- 18.5 => 0;
              21-23 :  4.0- 19.5 => 0;
              24-26 :  4.5- 21.5 => 0;
              27-29 :  5.0- 23.0 => 0;
              30-32 :  5.0- 24.5 => 0;
              33-35 :  5.0- 25.5 => 0;
              36-38 :  5.0- 27.0 => 0;
              39-41 :  5.0- 29.0 => 0;
              42-44 :  5.5- 29.0 => 0;
              45-47 :  5.5- 30.0 => 0;
              48-50 :  5.5- 31.0 => 0;
              51-53 :  5.5- 32.0 => 0;
              54-56 :  6.0- 33.0 => 0;
              57-60 :  6.0- 34.5 => 0;
              61-72 :  6.0- 36.0 => 0;
                    :            => 1;
          endbox
        endif;
        if hwerr then
          e=errmsg(4080,ln,WEIGHT,hwsex,hwage)
        endif;

        if (hwage >= 24 and AN2A = 1) or (hwage < 24 and AN2A = 2) then
          e=errmsg(4070,ln,AN2A,hwage)
        endif;

        hwsex = HL3(CHLNNO);
        hwage = di - ldob;
        if hwsex = 1 then
          box hwage : HEIGHT     => hwerr;
               0- 2 : 36.0- 74.0 => 0;
               3- 5 : 45.0- 83.0 => 0;
               6- 8 : 51.0- 87.0 => 0;
               9-11 : 56.0- 91.0 => 0;
              12-14 : 59.0- 96.0 => 0;
              15-17 : 62.0-100.0 => 0;
              18-20 : 64.0-104.0 => 0;
              21-23 : 65.0-107.0 => 0;
              24-26 : 67.0-109.0 => 0;
              27-29 : 69.0-112.0 => 0;
              30-32 : 70.0-115.0 => 0;
              33-35 : 71.0-119.0 => 0;
              36-38 : 73.0-121.0 => 0;
              39-41 : 74.0-124.0 => 0;
              42-44 : 75.0-127.0 => 0;
              45-47 : 77.0-129.9 => 0;
              48-50 : 79.0-132.0 => 0;
              51-53 : 79.0-134.0 => 0;
              54-56 : 90.0-136.0 => 0;
              57-60 : 82.0-139.0 => 0;
              61-72 : 82.0-140.0 => 0;
                    :            => 1;
          endbox
        else
          box hwage : HEIGHT     => hwerr;
               0- 2 : 36.0- 72.0 => 0;
               3- 5 : 44.0- 90.0 => 0;
               6- 8 : 50.0- 86.0 => 0;
               9-11 : 54.0- 90.0 => 0;
              12-14 : 57.0- 95.0 => 0;
              15-17 : 60.0- 99.0 => 0;
              18-20 : 62.0-102.0 => 0;
              21-23 : 64.0-106.0 => 0;
              24-26 : 66.0-107.0 => 0;
              27-29 : 69.0-111.0 => 0;
              30-32 : 69.0-114.0 => 0;
              33-35 : 71.0-117.0 => 0;
              36-38 : 72.0-120.0 => 0;
              39-41 : 74.0-122.0 => 0;
              42-44 : 75.0-124.0 => 0;
              45-47 : 77.0-126.9 => 0;
              48-50 : 79.0-129.0 => 0;
              51-53 : 79.0-131.0 => 0;
              54-56 : 81.0-133.0 => 0;
              57-60 : 81.0-136.0 => 0;
              61-72 : 81.0-137.0 => 0;
                    :            => 1;
          endbox
        endif;
        if hwerr then
          e=errmsg(4060,ln,HEIGHT,hwsex,hwage)
        endif;

        if HEIGHT <> 997.0 and age <> 999.99 and (FLAG = 1 or FLAG = 3 or FLAG = 5 or FLAG = 7) then
          e=errmsg(4060,ln,HEIGHT,hwsex,hwage);
        endif;
        if WEIGHT <>  97.0 and age <> 999.99 and (FLAG = 4 or FLAG = 5 or FLAG = 6 or FLAG = 7) then
          e=errmsg(4080,ln,WEIGHT,hwsex,hwage);
        endif;
        if HEIGHT <> 997.0 and WEIGHT <> 97.0 and (FLAG = 2 or FLAG = 3 or FLAG = 6 or FLAG = 7) then
          e=errmsg(4090,ln,HEIGHT,WEIGHT);
        endif;

        if (AN4  = 1 and (WEIGHT >= 97.0  or HEIGHT >= 997.0)) or
           (AN4 <> 1 and (WEIGHT <  97.0 and HEIGHT <  997.0)) then
          e=errmsg(4100,ln);
        endif;

      endif; { Child loaded }

    endif; { Child eligible }

    ln = ln + 1;
  enddo; { Loop for children }

endif; { Complete household interview }
